@@ -51,7 +51,7 @@ class MarkdownRenderer:
         # Fonts
         pygame.font.init()
         self.font_normal_str = 'Arial'
-        self.font_code_str = 'CourierNew'
+        self.font_code_str = 'Courier'
         self.font_header_size = 28
         self.font_header = pygame.font.SysFont(self.font_normal_str, self.font_header_size, bold=True)
         self.font_header2_size = 24
@@ -70,6 +70,7 @@ class MarkdownRenderer:
         self.gap_paragraph = 35
         self.indentation_quote = 25
         self.indentation_code = 25
+        self.code_padding = 2
 
         # Scrollbar
         self.pixel_scroll_step = 25
@@ -109,15 +110,25 @@ class MarkdownRenderer:
                 block = self.html[start.span()[1]:  end.span()[0]]
 
                 if block_type == 'p':  # test whether the paragraph is actually a nested code block
-                    rex = re.search(r'^<code>[\s\S]+<\/code>$', block)
+                    rex = re.search(r'^<code>[\s\S]+<\/code>$', block.strip(' '))
                     if rex is not None:
                         block_type = 'codeblock'
-                        block = block[6:-7]
+                        block = block.strip(' ')[6:-7]
 
                 self.html = self.html[end.span()[1]:]
                 self.blocks.append((block, block_type))
 
     def set_area(self, surface, offset_x, offset_y, width=-1, height=-1, margin=10) -> None:
+        """
+        TODO: missing docstring
+        :param surface:
+        :param offset_x:
+        :param offset_y:
+        :param width:
+        :param height:
+        :param margin:
+        :return:
+        """
         self.margin = margin
         # for simplicity, margin is subtracted from the initial x, y, w and h.
         # When rendering the background rect, we add the margin.
@@ -126,13 +137,21 @@ class MarkdownRenderer:
         self.x = offset_x + margin
         self.y = offset_y + margin
         # if no values are given, we take the end of the screen as limit.
-        self.w = width - (2 * self.margin) if width > 0 else surface.get_width() - self.x - (2 * self.margin)
-        self.h = height - (2 * self.margin) if height > 0 else surface.get_height() - self.y - (2 * self.margin)
+        self.w = width - (2 * self.margin) if width > 0 else surface.get_width() - offset_x - (2 * self.margin)
+        self.h = height - (2 * self.margin) if height > 0 else surface.get_height() - offset_y - (2 * self.margin)
         self.pixels_showable_at_once = self.h
         self.screen = surface
 
     def display(self, pygame_events, mouse_x, mouse_y, mouse_pressed):
-        # Background
+        """
+        TODO: missing docstring
+        :param pygame_events:
+        :param mouse_x:
+        :param mouse_y:
+        :param mouse_pressed:
+        :return:
+        """
+        # Background -> reverse the margins
         pygame.draw.rect(self.screen, self.color_area_background, (self.x - self.margin, self.y - self.margin,
                                                                    self.w + (2 * self.margin), self.h + (2 * self.margin)))
 
